@@ -3,10 +3,12 @@
 
 "bdk" <- function(data, Y, grid = somgrid(), rlen = 100,
                   alpha = c(0.05, 0.01),
-                  radius = quantile(nhbrdist, 0.67),
+                  radius = quantile(nhbrdist, 0.67) * c(1, -1),
                   xweight = 0.75, contin = !(all(rowSums(Y) == 1)),
-                  toroidal = FALSE, keep.data = TRUE)
+                  toroidal = FALSE, n.hood, keep.data = TRUE)
 {
+  if (!is.numeric(data))
+    stop("Argument data should be numeric")
   data <- as.matrix(data)
   
   nd <- nrow(data)
@@ -28,7 +30,19 @@
     codeYs <- Y[starters,]
   }
   
+  if (missing(n.hood)) {
+    n.hood <- switch(grid$topo,
+                     hexagonal = "circular",
+                     rectangular = "square")
+  } else {
+    n.hood <- match.arg(n.hood, c("circular", "square"))
+  }
+  grid$n.hood <- n.hood
   nhbrdist <- unit.distances(grid, toroidal)
+
+  if (length(radius) == 1)
+    radius <- sort(radius * c(1, -1), decreasing = TRUE)
+
   changes <- rep(0, rlen*2)
 
   if (contin) {
@@ -39,7 +53,7 @@
               codeYs = as.double(codeYs),
               nhbrdist = as.double(nhbrdist),
               alpha = as.double(alpha),
-              radius = as.double(radius),
+              radii = as.double(radius),
               xweight = as.double(xweight),
               changes = as.double(changes),
               xdists = as.double(xdists),
@@ -81,14 +95,15 @@
     
     structure(list(data = data, Y = Y, contin = contin,
                    grid = grid, codes = codes,
-                   changes = changes, toroidal = toroidal,
+                   changes = changes, alpha = alpha,
+                   radius = radius, toroidal = toroidal,
                    unit.classif = mapping$unit.classif,
                    distances = mapping$distances, method="bdk"),
               class = "kohonen")
   } else {
-    structure(list(contin = contin,
-                   grid = grid, codes = codes,
-                   changes = changes, toroidal = toroidal, method="bdk"),
+    structure(list(contin = contin, grid = grid, codes = codes,
+                   changes = changes, alpha = alpha,
+                   radius = radius, toroidal = toroidal, method="bdk"),
               class = "kohonen")
   }
 }
